/*
 * libfeedback
 * Copyright (c) 2016 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __FEEDBACK_IDS_INTERNAL_H__
#define __FEEDBACK_IDS_INTERNAL_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @file feedback-ids-internal.h
 * @brief This file contains the feedback API
 */

/**
 * @addtogroup CAPI_FEEDBACK_MODULE
 * @{
 */

/**
 * @brief Enumerations of the system pre-defined patterns for feedback interface
 * @details
 * Each feedback pattern can have separate media files of each types.
 * But Depending on vendor design, pattern may not have any type of file.
 *
 */
typedef enum {
	FEEDBACK_PATTERN_INTERNAL_NONE = -1,


	FEEDBACK_PATTERN_MESSAGE_ON_CALL = 24,		/**< feedback pattern when incoming a message on call */
	FEEDBACK_PATTERN_EMAIL_ON_CALL = 26,		/**< feedback pattern when incoming an email on call */
	FEEDBACK_PATTERN_WAKEUP_ON_CALL = 28,		/**< feedback pattern when alert wake up call on call */
	FEEDBACK_PATTERN_SCHEDULE_ON_CALL = 30,		/**< feedback pattern when alert schedule alarm on call */
	FEEDBACK_PATTERN_TIMER_ON_CALL = 32,		/**< feedback pattern when alert timer on call */
	FEEDBACK_PATTERN_GENERAL_ON_CALL = 34,		/**< feedback pattern when alert general event on call */

	FEEDBACK_PATTERN_CHARGERCONN_ON_CALL = 39,	/**< feedback pattern when connecting charger on call */
	FEEDBACK_PATTERN_CHARGING_ERROR_ON_CALL = 41,	/**< feedback pattern when occuring charging error on call */
	FEEDBACK_PATTERN_FULLCHARGED_ON_CALL = 43,	/**< feedback pattern when full charged on call */
	FEEDBACK_PATTERN_LOWBATT_ON_CALL = 45,		/**< feedback pattern when low battery on call */

	FEEDBACK_PATTERN_OUTGOING_CALL = 53,		/**< feedback pattern when connected outgoing call */
	FEEDBACK_PATTERN_SCREEN_CAPTURE = 61,		/**< feedback pattern when screen capture */

	FEEDBACK_PATTERN_SEND_SOS_MESSAGE = 74,		/**< feedback pattern when sending SOS message */
	FEEDBACK_PATTERN_RINGER,			/**< Feedback pattern for incoming call */
	FEEDBACK_PATTERN_NOTIFICATION,			/**< Feedback pattern for notification */
	FEEDBACK_PATTERN_INFO,				/**< Feedback pattern for information */
	FEEDBACK_PATTERN_WARNING,			/**< Feedback pattern for warning */
	FEEDBACK_PATTERN_ERROR,				/**< Feedback pattern for error */
	FEEDBACK_PATTERN_EMERGENCY,			/**< Feedback pattern for emergency */

	FEEDBACK_PATTERN_INTERNAL_END,
} feedback_pattern_internal_e;

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif //__FEEDBACK_IDS_INTERNAL_H__
